@@ -3,7 +3,7 @@
 from continuum.datasets.base import (
     ImageFolderDataset, InMemoryDataset, PyTorchDataset, _ContinuumDataset
 )
-from continuum.datasets.core50 import CORe50
+from continuum.datasets.core50 import (CORe50, CORe50v2_79, CORe50v2_196, CORe50v2_391)
 from continuum.datasets.fellowship import (CIFARFellowship, Fellowship, MNISTFellowship)
 from continuum.datasets.imagenet import ImageNet100, ImageNet1000
 from continuum.datasets.nlp import MultiNLI
