@@ -1,9 +1,13 @@
 import os
+import tarfile
 import urllib.request
 import zipfile
 
 
 def download(url, path):
+    if not os.path.exists(path):
+        os.makedirs(path)
+
     file_name = os.path.join(path, url.split("/")[-1])
 
     if os.path.exists(file_name):
@@ -19,10 +23,14 @@ def download(url, path):
 
 def unzip(path):
     directory_path = os.path.dirname(path)
+    with zipfile.ZipFile(path, 'r') as f:
+        f.extractall(directory_path)
 
-    with zipfile.ZipFile(path, 'r') as zip_ref:
-        zip_ref.extractall(directory_path)
-    print(f"Dataset extracted at {directory_path}")
+
+def untar(path):
+    directory_path = os.path.dirname(path)
+    with tarfile.open(path) as f:
+        f.extractall(directory_path)
 
 
 class ProgressBar:
@@ -34,8 +42,7 @@ class ProgressBar:
     def __init__(self):
         self.count = 0
 
-    def update(self, urlretrieve_inputs):
-        _, block_size, total_size = urlretrieve_inputs
+    def update(self, tmp, block_size, total_size):
         self.count += block_size
 
         percent = f"{int(100 * self.count / total_size)}"
